@@ -20,6 +20,8 @@ from owslib import fes2
 from owslib import util
 from owslib import ows
 from owslib.iso import MD_Metadata, FC_FeatureCatalogue
+from owslib.iso3 import MD_Metadata as MD_Metadata3  # ISO 19115 Part 3 XML
+from owslib.iso3 import FC_FeatureCatalogue as FC_FeatureCatalogue3  # ISO 19115 Part 3 XML
 from owslib.fgdc import Metadata
 from owslib.dif import DIF
 from owslib.gm03 import GM03
@@ -143,23 +145,25 @@ class CatalogueServiceWeb(object):
         etree.SubElement(node0, util.nspath_eval('csw30:%s' % dtypename, namespaces)).text = dname
 
         self.request = node0
+        try:  # getdomain operation is optional on CSW3, return empty if failing
+            self._invoke()
 
-        self._invoke()
+            if self.exceptionreport is None:
+                self.results = {}
 
-        if self.exceptionreport is None:
-            self.results = {}
+                val = self._exml.find(util.nspath_eval('csw30:DomainValues', namespaces)).attrib.get('type')
+                self.results['type'] = util.testXMLValue(val, True)
 
-            val = self._exml.find(util.nspath_eval('csw30:DomainValues', namespaces)).attrib.get('type')
-            self.results['type'] = util.testXMLValue(val, True)
+                val = self._exml.find(util.nspath_eval('csw30:DomainValues/csw30:%s' % dtypename, namespaces))
+                self.results[dtype] = util.testXMLValue(val)
 
-            val = self._exml.find(util.nspath_eval('csw30:DomainValues/csw30:%s' % dtypename, namespaces))
-            self.results[dtype] = util.testXMLValue(val)
+                # get the list of values associated with the Domain
+                self.results['values'] = []
 
-            # get the list of values associated with the Domain
-            self.results['values'] = []
-
-            for f in self._exml.findall(util.nspath_eval('csw30:DomainValues/csw30:ListOfValues/csw30:Value', namespaces)):  # noqa
-                self.results['values'].append(util.testXMLValue(f))
+                for f in self._exml.findall(util.nspath_eval('csw30:DomainValues/csw30:ListOfValues/csw30:Value', namespaces)):  # noqa
+                    self.results['values'].append(util.testXMLValue(f))
+        except Exception:
+            self.results = {'values': []}
 
     def getrecordbyid(self, id=[], esn='full', outputschema=namespaces['csw30'], format=outputformat):
         """
@@ -477,6 +481,12 @@ class CatalogueServiceWeb(object):
                 val = i.find(util.nspath_eval('gm03:fileIdentifier', namespaces))
                 identifier = self._setidentifierkey(util.testXMLValue(val))
                 self.records[identifier] = GM03(i)
+        elif MD_Metadata3.handles(outputschema):  # ISO 19115 Part 3 XML
+            for elem, id in MD_Metadata3.find_ids(self._exml):
+                self.records[self._setidentifierkey(id)] = MD_Metadata3(elem)
+            for i in self._exml.findall('.//' + util.nspath_eval('gfc:FC_FeatureCatalogue', namespaces)):
+                identifier = self._setidentifierkey(util.testXMLValue(i.attrib['uuid'], attrib=True))
+                self.records[identifier] = FC_FeatureCatalogue3(i)
         else:  # process default
             for i in self._exml.findall('.//' + util.nspath_eval('csw30:%s' % self._setesnel(esn), namespaces)):
                 val = i.find(util.nspath_eval('dc:identifier', namespaces))
@@ -549,15 +559,16 @@ class CatalogueServiceWeb(object):
                     post_verbs = [x for x in op.methods if x.get('type').lower() == 'post']
                     if len(post_verbs) > 1:
                         # Filter by constraints.  We must match a PostEncoding of "XML"
+                        found_xml = False
                         for pv in post_verbs:
                             for const in pv.get('constraints'):
                                 if const.name.lower() == 'postencoding':
                                     values = [v.lower() for v in const.values]
                                     if 'xml' in values:
                                         request_url = pv.get('url')
+                                        found_xml = True
                                         break
-                        else:
-                            # Well, just use the first one.
+                        if not found_xml:  # Well, just use the first one.
                             request_url = post_verbs[0].get('url')
                     elif len(post_verbs) == 1:
                         request_url = post_verbs[0].get('url')
