@@ -9,8 +9,6 @@
 
 """ API for OGC CRS constructs. """
 
-from __future__ import (absolute_import, division, print_function)
-
 # list of URN codes for EPSG in which axis order
 # of coordinates are y,x (e.g. lat, long)
 axisorder_yx = frozenset([
@@ -1719,6 +1717,7 @@ axisorder_yx = frozenset([
     31700
 ])
 
+
 class Crs(object):
     """Initialize a CRS construct
 
@@ -1747,16 +1746,19 @@ class Crs(object):
 
         values = self.id.split(':')
 
-        if self.id.find('/def/crs/') != -1: # URI Style 1
+        if self.id.find('/def/crs/') != -1:  # URI Style 1
             self.encoding = "uri"
             vals = self.id.split('/')
             self.authority = vals[5].upper()
-            self.code = int(vals[-1])
+            self.code = vals[-1]
+            self.version = vals[-2]
+            if self.version == '0':
+                self.version = None
         elif self.id.find('#') != -1:  # URI Style 2
             self.encoding = "uri"
             vals = self.id.split('#')
             self.authority = vals[0].split('/')[-1].split('.')[0].upper()
-            self.code = int(vals[-1])
+            self.code = vals[-1]
         elif len(values) > 2:  # it's a URN style
             self.naming_authority = values[1]
             self.encoding = "urn"
@@ -1773,17 +1775,20 @@ class Crs(object):
             if len(values) == 7:  # version, even if empty, is included
                 if values[5]:
                     self.version = values[5]
-
-            # code is always the last value
-            try:
-                self.code = int(values[-1])
-            except:
-                self.code = values[-1]
+            self.code = values[-1]
 
         elif len(values) == 2:  # it's an authority:code code
             self.encoding = "code"
             self.authority = values[0].upper()
-            self.code = int(values[1])
+            self.code = values[1]
+
+        # convert code if possible for int mapping with axisorder
+        # if not an int, it can be another code such as CRS84
+        # from http://www.opengis.net/def/crs/OGC/1.3/CRS84
+        try:
+            self.code = int(self.code)
+        except (TypeError, ValueError):
+            pass
 
         # if the user has not forced the axisorder,
         # scan the list of codes that have an axis ordering of
@@ -1792,7 +1797,6 @@ class Crs(object):
             if self.code in axisorder_yx:
                 self.axisorder = 'yx'
 
-
     def getcode(self):
         """Create for example "EPSG:4326" string and return back
 
@@ -1809,11 +1813,11 @@ class Crs(object):
         :returns: String code formated in "urn:ogc:def:authority:code"
         """
 
-        return 'urn:%s:def:crs:%s:%s:%s' % (
-                    (self.naming_authority and self.naming_authority or "ogc"),
-                                    (self.authority or ""),
-                                    (self.version or ""),
-                                    (self.code or ""))
+        return 'urn:{}:def:crs:{}:{}:{}'.format(
+            (self.naming_authority and self.naming_authority or "ogc"),
+            (self.authority or ""),
+            (self.version or ""),
+            (self.code or ""))
 
     def getcodeuri1(self):
         """Create for example "http://www.opengis.net/def/crs/EPSG/0/4326"
@@ -1822,7 +1826,11 @@ class Crs(object):
         :returns: String code formated in "http://www.opengis.net/def/crs/EPSG/0/code"
         """
 
-        return 'http://www.opengis.net/def/crs/EPSG/0/%s' % self.code
+        return 'http://www.opengis.net/def/crs/{}/{}/{}'.format(
+            self.authority or "EPSG",
+            self.version or "0",
+            self.code
+        )
 
     def getcodeuri2(self):
         """Create for example "http://www.opengis.net/gml/srs/epsg.xml#4326"
@@ -1839,5 +1847,8 @@ class Crs(object):
         else:
             return False
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def __repr__(self):
         return self.getcodeurn()
