@@ -10,7 +10,7 @@ SERVICE_URL = 'https://demo.pygeoapi.io/master/'
 @pytest.mark.online
 @pytest.mark.skipif(not service_ok(SERVICE_URL),
                     reason='service is unreachable')
-def test_ogcapi_coverages_pygeoapi():
+def test_ogcapi_edr_pygeoapi():
     w = EnvironmentalDataRetrieval(SERVICE_URL)
 
     assert w.url == SERVICE_URL
@@ -39,5 +39,5 @@ def test_ogcapi_coverages_pygeoapi():
     parameter_names = icoads['parameter_names'].keys()
     assert sorted(parameter_names) == ['AIRT', 'SST', 'UWND', 'VWND']
 
-    response = w.query_data('icoads-sst', 'position', coords='POINT(-75 45)')
+    response = w.query_data('icoads-sst', 'position', coords='POINT(0 0)')
     assert isinstance(response, dict)
